import sys

class Pysser():
    def __init__(self,interval=0.1):
        self.sser = None
        if sys.platform.startswith('linux'):
            from .ssermainlinux import SserMain
            self.sser = SserMain(interval=interval)
        else:
            from .ssermainwin import SserMain
            self.sser = SserMain(interval=interval)

    def init(self,port,baudrate,timeout) -> None:
        self.sser.init(port=port,baudrate=baudrate,timeout=timeout)

        
    def flush(self):
        self.sser.flush()

    def close(self) -> None:
        self.sser.close()

    def open(self):
        self.sser.open()

    def is_open(self):
        return self.sser.is_open()
    
    def docommand(self, command, no_response=False, timeout=3, size=1):
        return self.sser.docommand(command=command,no_response=no_response,timeout=timeout,size=size)
    
    def read(self,size=1):
        return self.sser.read(size=size)
    
    def write(self,data):
        self.sser.write(data=data)

    def set_interval(self, interval):
        self.sser.set_interval(interval=interval)


from setuptools import setup, find_packages ,Extension


setup(
    name="pysser",
    version="1.1.18",
    packages=find_packages(),
    install_requires=[
        # 在这里列出你的库所需的其他Python包
        "pyserial==3.5",
    ],
    author="nbigbug",
    author_email="nbigbug@126.com",
    description="A special ser",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    license="MIT",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        'Operating System :: POSIX :: Linux',
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
)